@@ -97,16 +97,15 @@ class VirtTest(test.Test):
         :param vt_params: avocado-vt/cartesian_config params stored as
                           `self.params`.
         """
-        vt_params = kwargs.pop("vt_params", None)
-        self.__params_vt = None
+        self.__vt_params = None
         self.__avocado_params = None
         self.bindir = data_dir.get_root_dir()
         self.virtdir = os.path.join(self.bindir, 'shared')
-        # self.__params_vt must be initialized after super
-        params_vt = utils_params.Params(vt_params)
+        # self.__vt_params must be initialized after super
+        vt_params = utils_params.Params(kwargs.pop("vt_params", None))
         # for timeout use Avocado-vt timeout as default but allow
         # overriding from Avocado params (varianter)
-        self.timeout = params_vt.get("test_timeout", self.timeout)
+        self.timeout = vt_params.get("test_timeout", self.timeout)
 
         self.iteration = 0
         self.resultsdir = None
@@ -129,7 +128,7 @@ class VirtTest(test.Test):
             # 36LTS set's `self.params` instead of having it as a property
             # which stores the avocado params in `self.__params`
             self.__avocado_params = self.__params
-        self.__params_vt = params_vt
+        self.__vt_params = vt_params
         self.debugdir = self.logdir
         self.resultsdir = self.logdir
         utils_misc.set_log_file_dir(self.logdir)
@@ -145,21 +144,14 @@ class VirtTest(test.Test):
         once the Avocado-vt params are set it reports those instead. This
         is necessary to complete the `avocado.Test.__init__` phase
         """
-        if self.__params_vt is not None:
-            return self.__params_vt
+        if self.__vt_params is not None:
+            return self.__vt_params
         else:
             # The `self.__params` is set after the `avocado.test.__init__`,
             # but in newer Avocado `self.params` is used during `__init__`
             # Report the parent's value in such case.
             return super(VirtTest, self).params
 
-    @params.setter
-    def params(self, value):
-        """
-        For compatibility with 36lts we need to support setter on params
-        """
-        self.__params_vt = value
-
     @property
     def avocado_params(self):
         """
@@ -188,18 +180,6 @@ class VirtTest(test.Test):
         """
         return None
 
-    def get_state(self):
-        """
-        Pre Avocado-60.0 used to override self.__params attribute and
-        requires special handling while reporting the state.
-
-        TODO: Remove when 52LTS is deprecated.
-        """
-        state = super(VirtTest, self).get_state()
-        if state["params"] == self.__params_vt:
-            state["params"] = self.avocado_params
-        return state
-
     def write_test_keyval(self, d):
         self.whiteboard = str(d)
 
@@ -315,11 +295,6 @@ class VirtTest(test.Test):
     def _runTest(self):
         params = self.params
 
-        # If a dependency test prior to this test has failed, let's fail
-        # it right away as TestNA.
-        if params.get("dependency_failed") == 'yes':
-            raise exceptions.TestSkipError("Test dependency failed")
-
         # Report virt test version
         logging.info(version.get_pretty_version_info())
         # Report the parameters we've received and write them as keyvals
