@@ -23,7 +23,6 @@ from virttest import utils_net
 from virttest import data_dir
 from virttest import utils_package
 from virttest.staging import service
-from virttest.compat_52lts import results_stderr_52lts, decode_to_text
 
 
 ISCSI_CONFIG_FILE = "/etc/iscsi/initiatorname.iscsi"
@@ -77,7 +76,7 @@ def iscsi_get_sessions():
     """
     cmd = "iscsiadm --mode session"
 
-    output = decode_to_text(process.system_output(cmd, ignore_status=True))
+    output = process.run(cmd, ignore_status=True).stdout_text
     sessions = []
     if "No active sessions" not in output:
         for session in output.splitlines():
@@ -93,7 +92,7 @@ def iscsi_get_nodes():
     """
     cmd = "iscsiadm --mode node"
 
-    output = decode_to_text(process.system_output(cmd, ignore_status=True))
+    output = process.run(cmd, ignore_status=True).stdout_text
     pattern = r"(\d+\.\d+\.\d+\.\d+|\[.+\]):\d+,\d+\s+([\w\.\-:\d]+)"
     nodes = []
     if "No records found" not in output:
@@ -110,7 +109,7 @@ def iscsi_login(target_name, portal):
     """
     cmd = "iscsiadm --mode node --login --targetname %s" % target_name
     cmd += " --portal %s" % portal
-    output = decode_to_text(process.system_output(cmd))
+    output = process.run(cmd).stdout_text
 
     target_login = ""
     if "successful" in output:
@@ -159,11 +158,11 @@ def iscsi_logout(target_name=None):
 
     output = ''
     try:
-        output = decode_to_text(process.system_output(cmd))
+        output = process.run(cmd).stdout_text
     except process.CmdError as detail:
         # iscsiadm will fail when no matching sessions found
         # This failure makes no sense when target name is not specified
-        stderr = results_stderr_52lts(detail.result)
+        stderr = detail.result.stderr_text
         if not target_name and 'No matching sessions' in stderr:
             logging.info("%s: %s", detail, stderr)
         else:
@@ -183,7 +182,7 @@ def iscsi_discover(portal_ip):
     :param portal_ip: Ip for iscsi server
     """
     cmd = "iscsiadm -m discovery -t sendtargets -p %s" % portal_ip
-    output = decode_to_text(process.system_output(cmd, ignore_status=True))
+    output = process.run(cmd, ignore_status=True).stdout_text
 
     session = ""
     if "Invalid" in output:
@@ -319,7 +318,7 @@ class _IscsiComm(object):
         pattern = r"%s.*?disk\s(\w+)\s+\S+\srunning" % self.target
         device_name = []
         if self.logged_in():
-            output = decode_to_text(process.system_output(cmd))
+            output = process.run(cmd).stdout_text
             targets = output.split('Target: ')[1:]
             for target in targets:
                 if self.target in target:
@@ -395,7 +394,7 @@ class IscsiTGT(_IscsiComm):
         Get target id from image name. Only works for emulated iscsi device
         """
         cmd = "tgtadm --lld iscsi --mode target --op show"
-        target_info = decode_to_text(process.system_output(cmd))
+        target_info = process.run(cmd).stdout_text
         target_id = ""
         for line in re.split("\n", target_info):
             if re.findall("Target\s+(\d+)", line):
@@ -413,7 +412,7 @@ class IscsiTGT(_IscsiComm):
         Get all CHAP authentication accounts
         """
         cmd = "tgtadm --lld iscsi --op show --mode account"
-        all_accounts = decode_to_text(process.system_output(cmd))
+        all_accounts = process.run(cmd).stdout_text
         if all_accounts:
             all_accounts = list(map(str.strip, all_accounts.splitlines()[1:]))
         return all_accounts
@@ -448,7 +447,7 @@ class IscsiTGT(_IscsiComm):
         Get the target account information
         """
         cmd = "tgtadm --lld iscsi --mode target --op show"
-        target_info = decode_to_text(process.system_output(cmd))
+        target_info = process.run(cmd).stdout_text
         pattern = r"Target\s+\d:\s+%s" % self.target
         pattern += ".*Account information:\s(.*)ACL information"
         try:
@@ -488,10 +487,10 @@ class IscsiTGT(_IscsiComm):
                 process.system(self.create_cmd)
         cmd = "tgtadm --lld iscsi --mode target --op show"
         try:
-            output = decode_to_text(process.system_output(cmd))
+            output = process.run(cmd).stdout_text
         except process.CmdError:
             restart_tgtd()
-            output = decode_to_text(process.system_output(cmd))
+            output = process.run(cmd).stdout_text
         if not re.findall("%s$" % self.target, output, re.M):
             logging.debug("Need to export target in host")
 
@@ -501,7 +500,7 @@ class IscsiTGT(_IscsiComm):
                 selinux_mode = utils_selinux.get_status()
                 utils_selinux.set_status("permissive")
 
-            output = decode_to_text(process.system_output(cmd))
+            output = process.run(cmd).stdout_text
             used_id = re.findall("Target\s+(\d+)", output)
             emulated_id = 1
             while str(emulated_id) in used_id:
@@ -520,10 +519,10 @@ class IscsiTGT(_IscsiComm):
 
         cmd = "tgtadm --lld iscsi --mode target --op show"
         try:
-            output = decode_to_text(process.system_output(cmd))
+            output = process.run(cmd).stdout_text
         except process.CmdError:   # In case service stopped
             restart_tgtd()
-            output = decode_to_text(process.system_output(cmd))
+            output = process.run(cmd).stdout_text
 
         # Create a LUN with emulated image
         if re.findall(self.emulated_image, output, re.M):
@@ -562,7 +561,7 @@ class IscsiTGT(_IscsiComm):
         Delete target from host.
         """
         cmd = "tgtadm --lld iscsi --mode target --op show"
-        output = decode_to_text(process.system_output(cmd))
+        output = process.run(cmd).stdout_text
         if re.findall("%s$" % self.target, output, re.M):
             if self.emulated_id:
                 cmd = "tgtadm --lld iscsi --mode target --op delete "
@@ -591,7 +590,7 @@ class IscsiLIO(_IscsiComm):
         Get target id from image name.
         """
         cmd = "targetcli ls /iscsi 1"
-        target_info = decode_to_text(process.system_output(cmd))
+        target_info = process.run(cmd).stdout_text
         target = None
         for line in re.split("\n", target_info)[1:]:
             if re.findall("o-\s\S+\s[\.]+\s\[TPGs:\s\d\]$", line):
@@ -605,7 +604,7 @@ class IscsiLIO(_IscsiComm):
                 continue
 
             cmd = "targetcli ls /iscsi/%s/tpg1/luns" % target
-            luns_info = decode_to_text(process.system_output(cmd))
+            luns_info = process.run(cmd).stdout_text
             for lun_line in re.split("\n", luns_info):
                 if re.findall("o-\slun\d+", lun_line):
                     if self.emulated_image in lun_line:
@@ -632,7 +631,7 @@ class IscsiLIO(_IscsiComm):
         # Create user and allow access
         acls_cmd = ("targetcli /iscsi/%s/tpg1/acls/ create %s:client"
                     % (self.target, self.target.split(":")[0]))
-        output = decode_to_text(process.system_output(acls_cmd))
+        output = process.run(acls_cmd).stdout_text
         if "Created Node ACL" not in output:
             raise exceptions.TestFail("Failed to create ACL. (%s)" % output)
 
@@ -640,13 +639,13 @@ class IscsiLIO(_IscsiComm):
                     % (self.target, self.target.split(":")[0]))
         # Set userid
         userid_cmd = "%s set auth userid=%s" % (comm_cmd, self.chap_user)
-        output = decode_to_text(process.system_output(userid_cmd))
+        output = process.run(userid_cmd).stdout_text
         if self.chap_user not in output:
             raise exceptions.TestFail("Failed to set user. (%s)" % output)
 
         # Set password
         passwd_cmd = "%s set auth password=%s" % (comm_cmd, self.chap_passwd)
-        output = decode_to_text(process.system_output(passwd_cmd))
+        output = process.run(passwd_cmd).stdout_text
         if self.chap_passwd not in output:
             raise exceptions.TestFail("Failed to set password. (%s)" % output)
 
@@ -668,13 +667,13 @@ class IscsiLIO(_IscsiComm):
 
         # Set userid
         userid_cmd = "%s set auth userid=%s" % (auth_cmd, self.chap_user)
-        output = decode_to_text(process.system_output(userid_cmd))
+        output = process.run(userid_cmd).stdout_text
         if self.chap_user not in output:
             raise exceptions.TestFail("Failed to set user. (%s)" % output)
 
         # Set password
         passwd_cmd = "%s set auth password=%s" % (auth_cmd, self.chap_passwd)
-        output = decode_to_text(process.system_output(passwd_cmd))
+        output = process.run(passwd_cmd).stdout_text
         if self.chap_passwd not in output:
             raise exceptions.TestFail("Failed to set password. (%s)" % output)
 
@@ -698,7 +697,7 @@ class IscsiLIO(_IscsiComm):
 
         # confirm if the target exists and create iSCSI target
         cmd = "targetcli ls /iscsi 1"
-        output = decode_to_text(process.system_output(cmd))
+        output = process.run(cmd).stdout_text
         if not re.findall("%s$" % self.target, output, re.M):
             logging.debug("Need to export target in host")
 
@@ -723,27 +722,27 @@ class IscsiLIO(_IscsiComm):
             # Create a fileio backstore
             device_cmd = ("targetcli /backstores/fileio/ create %s %s" %
                           (self.device, self.emulated_image))
-            output = decode_to_text(process.system_output(device_cmd))
+            output = process.run(device_cmd).stdout_text
             if "Created fileio" not in output:
                 raise exceptions.TestFail("Failed to create fileio %s. (%s)" %
                                           (self.device, output))
 
             # Create an IQN with a target named target_name
             target_cmd = "targetcli /iscsi/ create %s" % self.target
-            output = decode_to_text(process.system_output(target_cmd))
+            output = process.run(target_cmd).stdout_text
             if "Created target" not in output:
                 raise exceptions.TestFail("Failed to create target %s. (%s)" %
                                           (self.target, output))
 
             check_portal = "targetcli /iscsi/%s/tpg1/portals ls" % self.target
-            portal_info = decode_to_text(process.system_output(check_portal))
+            portal_info = process.run(check_portal).stdout_text
             if "0.0.0.0:3260" not in portal_info:
                 # Create portal
                 # 0.0.0.0 means binding to INADDR_ANY
                 # and using default IP port 3260
                 portal_cmd = ("targetcli /iscsi/%s/tpg1/portals/ create %s"
                               % (self.target, "0.0.0.0"))
-                output = decode_to_text(process.system_output(portal_cmd))
+                output = process.run(portal_cmd).stdout_text
                 if "Created network portal" not in output:
                     raise exceptions.TestFail("Failed to create portal. (%s)" %
                                               output)
@@ -753,14 +752,14 @@ class IscsiLIO(_IscsiComm):
                 # create ipv6 portal if needed.
                 portal_cmd = ("targetcli /iscsi/%s/tpg1/portals/ create %s"
                               % (self.target, self.portal_ip))
-                output = decode_to_text(process.system_output(portal_cmd))
+                output = process.run(portal_cmd).stdout_text
                 if "Created network portal" not in output:
                     raise exceptions.TestFail("Failed to create portal. (%s)" %
                                               output)
             # Create lun
             lun_cmd = "targetcli /iscsi/%s/tpg1/luns/ " % self.target
             dev_cmd = "create /backstores/fileio/%s" % self.device
-            output = decode_to_text(process.system_output(lun_cmd + dev_cmd))
+            output = process.run(lun_cmd + dev_cmd).stdout_text
             luns = re.findall(r"Created LUN (\d+).", output)
             if not luns:
                 raise exceptions.TestFail("Failed to create lun. (%s)" %
@@ -768,8 +767,8 @@ class IscsiLIO(_IscsiComm):
             self.luns = luns[0]
 
             # Set firewall if it's enabled
-            output = decode_to_text(process.system_output("firewall-cmd --state",
-                                                          ignore_status=True))
+            output = process.run("firewall-cmd --state",
+                                 ignore_status=True).stdout_text
             if re.findall("^running", output, re.M):
                 # firewall is running
                 process.system("firewall-cmd --permanent --add-port=3260/tcp")
@@ -801,7 +800,7 @@ class IscsiLIO(_IscsiComm):
                          "demo_mode_write_protect=0",
                          "generate_node_acls=1",
                          "cache_dynamic_acls=1"))
-            output = decode_to_text(process.system_output(auth_cmd + attr_cmd))
+            output = process.run(auth_cmd + attr_cmd).stdout_text
             logging.info("Define access rights: %s" % output)
             # Discovery the target
             self.portal_visible()
@@ -819,7 +818,7 @@ class IscsiLIO(_IscsiComm):
         # Delete block
         if self.device is not None:
             cmd = "targetcli /backstores/fileio ls"
-            output = decode_to_text(process.system_output(cmd))
+            output = process.run(cmd).stdout_text
             if re.findall("%s" % self.device, output, re.M):
                 dev_del = ("targetcli /backstores/fileio/ delete %s"
                            % self.device)
@@ -827,7 +826,7 @@ class IscsiLIO(_IscsiComm):
 
         # Delete IQN
         cmd = "targetcli ls /iscsi 1"
-        output = decode_to_text(process.system_output(cmd))
+        output = process.run(cmd).stdout_text
         if re.findall("%s" % self.target, output, re.M):
             del_cmd = "targetcli /iscsi delete %s" % self.target
             process.system(del_cmd)
