@@ -9,6 +9,7 @@ import re
 
 from avocado.utils import process
 
+from virttest import utils_disk
 from virttest import virsh
 from virttest.staging import utils_cgroup
 
@@ -134,17 +135,35 @@ class CgroupTest(object):
                           the blkio related cgroup info will be returned
         :return: A dict containing the cgroup info
         """
+
+        def __get_cg_file_path(cg_key, cg_path, cg_file_name):
+            """
+            Get the path to a cgroup param file
+
+            :param cg_key: The cgroup param name used in libvirt
+            :param cgroup_path: The cgroup root path
+            :param cg_file_name: The file name of the cgroup param
+            :return: The path to the cgroup param file
+            """
+            if cg_key in ["weight", "cpu_shares"] and "libvirt" in cg_path:
+                return os.path.join(cg_path.split("libvirt")[0], cg_file_name)
+            return os.path.join(cg_path, cg_file_name)
+
         standardized_cgroup_info = {}
         if virsh_cmd == "blkiotune":
             cgroup_path = self.get_cgroup_path("blkio")
             dev_init_dict = {"rbps": "max", "wbps": "max", "riops": "max",
                              "wiops": "max"}
             dev_list = []
+            if not self.is_bfq():
+                CGROUP_V1_BLKIO_FILE_MAPPING['weight'] = 'blkio.weight'
+                CGROUP_V1_BLKIO_FILE_MAPPING['weight_device'] = 'blkio.weight_device'
             for cg_key, cg_file_name in list(CGROUP_V1_BLKIO_FILE_MAPPING.items()):
-                with open(os.path.join(cgroup_path, cg_file_name), 'r') as cg_file:
+                cg_file_path = __get_cg_file_path(cg_key, cgroup_path, cg_file_name)
+                with open(cg_file_path, 'r') as cg_file:
                     if cg_key in ["weight"]:
                         standardized_cgroup_info[cg_key] = cg_file.read().strip()
-                    if cg_key in ["rbps", "wbps", "riops", "wiops"]:
+                    if cg_key in ["rbps", "wbps", "riops", "wiops", "weight_device"]:
                         for line in cg_file.readlines():
                             dev_info = line.strip().split()
                             dev_num = dev_info[0]
@@ -175,10 +194,16 @@ class CgroupTest(object):
                         cg_file_name = cg_file_name.replace("<iothreadX>", iothread_dirs[0])
                     else:
                         continue
-                with open(os.path.join(cgroup_path, cg_file_name), 'r') as cg_file:
+                cg_file_path = __get_cg_file_path(cg_key, cgroup_path, cg_file_name)
+                with open(cg_file_path, 'r') as cg_file:
                     cg_file_value = cg_file.read().strip()
                     if cg_file_value == max_cpu_value:
                         cg_file_value = "max"
+                    if "quota" in cg_key:
+                        if cg_file_value in ["-1", "18446744073709551",
+                                             "17592186044415"]:
+                            standardized_cgroup_info[cg_key] = "max"
+                            continue
                     standardized_cgroup_info[cg_key] = cg_file_value
         else:
             logging.error("You've provided a wrong virsh cmd: %s", virsh_cmd)
@@ -275,6 +300,19 @@ class CgroupTest(object):
             logging.error("There is no virsh cmd '%s'", virsh_cmd)
             return None
         result = func(vm_name, ignore_status=True)
+        return self.convert_virsh_output_to_dict(result)
+
+    def convert_virsh_output_to_dict(self, result):
+        """
+        Convert virsh command output to a dict.
+        This method is only applicable to the virsh command
+        with ':' in the output for now.
+
+        :param result: Virsh command's result.
+            For example, the result of virsh schedinfo, blkiotune, memtune.
+
+        :return: The virsh cmd output, as a dict.
+        """
         output = result.stdout_text.strip()
         output_list = output.splitlines()
         output_dict = {}
@@ -357,6 +395,21 @@ class CgroupTest(object):
             return None
         return standardized_virsh_output_info
 
+    def is_bfq(self):
+        """
+        Judge which scheduler is used, 'bfq' or 'cfq'
+
+        :return: bool, True if bfq is used, False if cfq is used
+        """
+
+        first_blk = utils_disk.get_first_disk()
+        schedulerfd = "/sys/block/%s/queue/scheduler" % first_blk
+        bfq_scheduler = False
+        with open(schedulerfd, 'r') as iosche:
+            if 'bfq' in iosche.readline():
+                bfq_scheduler = True
+        return bfq_scheduler
+
     def get_standardized_virsh_output_by_name(self, vm_name=None, virsh_cmd=None):
         """
         Get the standardized output of a vm with a certain virsh cmd
