@@ -10,7 +10,7 @@ from virttest.libvirt_xml import base
 # Avoid accidental names like __init__, librarian, and/or other support modules
 DEVICE_TYPES = ['disk', 'filesystem', 'controller', 'lease',
                 'hostdev', 'redirdev', 'smartcard', 'interface', 'input',
-                'hub', 'graphics', 'video', 'parallel', 'serial', 'console',
+                'hub', 'graphics', 'video', 'audio', 'parallel', 'serial', 'console',
                 'channel', 'sound', 'watchdog', 'memballoon', 'rng', 'vsock',
                 'seclabel', 'address', 'emulator', 'panic', 'memory', 'filterref',
                 'iommu', 'tpm']
