@@ -11,6 +11,7 @@ from avocado.core import exceptions
 
 from virttest import remote
 from virttest import virsh
+from virttest import utils_disk
 from virttest import utils_misc
 from virttest import test_setup
 from virttest import utils_net
@@ -37,12 +38,15 @@ class MigrationTest(object):
         # The CmdResult returned from virsh migrate command
         self.ret = None
 
-    def post_migration_check(self, vms, params, uptime, uri=None):
+    def post_migration_check(self, vms, params, uptime=None, uri=None):
         """
         Validating migration by performing checks in this method
+        * check vm state after migration
         * uptime of the migrated vm > uptime of vm before migration
         * ping vm from target host
-        * check vm state after migration
+            by setting "check_network_accessibility_after_mig" to "yes"
+        * check disk operations on the migrated VM
+            by setting "check_disk_after_mig" to "yes"
 
         :param vms: VM objects of migrating vms
         :param uptime: uptime dict of vms before migration
@@ -50,24 +54,35 @@ class MigrationTest(object):
         :return: updated dict of uptime
         """
         vm_state = params.get("virsh_migrated_state", "running")
-        ping_count = int(params.get("ping_count", 10))
         for vm in vms:
             if not libvirt.check_vm_state(vm.name, vm_state, uri=uri):
                 raise exceptions.TestFail("Migrated VMs failed to be in %s "
                                           "state at destination" % vm_state)
             logging.info("Guest state is '%s' at destination is as expected",
                          vm_state)
-            if "offline" not in params.get("migrate_options", ""):
-                vm_uptime = vm.uptime(connect_uri=uri)
-                logging.info("uptime of migrated VM %s: %s", vm.name,
-                             vm_uptime)
-                if vm_uptime < uptime[vm.name]:
-                    raise exceptions.TestFail("vm went for a reboot during "
-                                              "migration")
-                self.ping_vm(vm, params, uri=uri, ping_count=ping_count)
-                # update vm uptime to check when migrating back
-                uptime[vm.name] = vm_uptime
-                vm.verify_dmesg(connect_uri=uri)
+            if "offline" not in params.get("migrate_options", params.get("virsh_migrate_options", "")):
+                if uptime:
+                    vm_uptime = vm.uptime(connect_uri=uri)
+                    logging.info("uptime of migrated VM %s: %s", vm.name,
+                                 vm_uptime)
+                    if vm_uptime < uptime[vm.name]:
+                        raise exceptions.TestFail("vm went for a reboot during "
+                                                  "migration")
+
+                    # update vm uptime to check when migrating back
+                    uptime[vm.name] = vm_uptime
+                    vm.verify_dmesg(connect_uri=uri)
+                if params.get("check_network_accessibility_after_mig", "no") == "yes":
+                    ping_count = int(params.get("ping_count", 10))
+                    self.ping_vm(vm, params, uri=uri, ping_count=ping_count)
+                if params.get("check_disk_after_mig", "no") == "yes":
+                    disk_kname = params.get("check_disk_kname_after_mig", "vdb")
+                    backup_uri, vm.connect_uri = vm.connect_uri, uri
+                    vm.create_serial_console()
+                    vm_session_after_mig = vm.wait_for_serial_login(timeout=360)
+                    utils_disk.linux_disk_check(vm_session_after_mig, disk_kname)
+                    vm_session_after_mig.close()
+                    vm.connect_uri = backup_uri
         return uptime
 
     def ping_vm(self, vm, params, uri=None, ping_count=10,
@@ -263,59 +278,71 @@ class MigrationTest(object):
                      for process.run
 
         """
+        @virsh.EventTracker.wait_event
+        def _do_orderly_migration(vm_name, vm, srcuri, desturi, options=None,
+                                  thread_timeout=60, ignore_status=False,
+                                  func=None, virsh_opt="",
+                                  extra_opts="", **args):
+            migration_thread = threading.Thread(target=self.thread_func_migration,
+                                                args=(vm, desturi, options,
+                                                      ignore_status, virsh_opt,
+                                                      extra_opts))
+            migration_thread.start()
+            eclipse_time = 0
+            stime = int(time.time())
+            if func:
+                # Execute command once the migration is started
+                migrate_start_state = args.get("migrate_start_state", "paused")
+
+                # Wait for migration to start
+                migrate_options = ""
+                if options:
+                    migrate_options = str(options)
+                if extra_opts:
+                    migrate_options += " %s" % extra_opts
+
+                migration_started = self.wait_for_migration_start(
+                    vm, state=migrate_start_state,
+                    uri=desturi,
+                    migrate_options=migrate_options.strip())
+
+                if migration_started:
+                    logging.info("Migration started for %s", vm.name)
+                    time.sleep(3)  # To avoid executing the command lines before starting migration
+                    if func == process.run:
+                        try:
+                            func(args['func_params'], shell=args['shell'])
+                        except KeyError:
+                            func(args['func_params'])
+                    elif func == virsh.migrate_postcopy:
+                        func(vm.name, uri=srcuri, debug=True)
+                    else:
+                        if 'func_params' in args:
+                            func(args['func_params'])
+                        else:
+                            func()
+                else:
+                    logging.error("Migration failed to start for %s", vm.name)
+            eclipse_time = int(time.time()) - stime
+            logging.debug("start_time:%d, eclipse_time:%d", stime, eclipse_time)
+            if eclipse_time < thread_timeout:
+                migration_thread.join(thread_timeout - eclipse_time)
+            if migration_thread.is_alive():
+                logging.error("Migrate %s timeout.", migration_thread)
+                self.RET_LOCK.acquire()
+                self.RET_MIGRATION = False
+                self.RET_LOCK.release()
+
         for vm in vms:
             vm.connect_uri = args.get("virsh_uri", "qemu:///system")
         if migration_type == "orderly":
             for vm in vms:
-                migration_thread = threading.Thread(target=self.thread_func_migration,
-                                                    args=(vm, desturi, options,
-                                                          ignore_status, virsh_opt,
-                                                          extra_opts))
-                migration_thread.start()
-                eclipse_time = 0
-                stime = int(time.time())
-                if func:
-                    # Execute command once the migration is started
-                    migrate_start_state = args.get("migrate_start_state", "paused")
-
-                    # Wait for migration to start
-                    migrate_options = ""
-                    if options:
-                        migrate_options = str(options)
-                    if extra_opts:
-                        migrate_options += " %s" % extra_opts
-
-                    migration_started = self.wait_for_migration_start(vm, state=migrate_start_state,
-                                                                      uri=desturi,
-                                                                      migrate_options=migrate_options.strip())
-
-                    if migration_started:
-                        logging.info("Migration started for %s", vm.name)
-                        time.sleep(3)  # To avoid executing the command lines before starting migration
-                        if func == process.run:
-                            try:
-                                func(args['func_params'], shell=args['shell'])
-                            except KeyError:
-                                func(args['func_params'])
-                        elif func == virsh.migrate_postcopy:
-                            func(vm.name, uri=srcuri, debug=True)
-                        else:
-                            if 'func_params' in args:
-                                func(args['func_params'])
-                            else:
-                                func()
-                    else:
-                        logging.error("Migration failed to start for %s",
-                                      vm.name)
-                eclipse_time = int(time.time()) - stime
-                logging.debug("start_time:%d, eclipse_time:%d", stime, eclipse_time)
-                if eclipse_time < thread_timeout:
-                    migration_thread.join(thread_timeout - eclipse_time)
-                if migration_thread.is_alive():
-                    logging.error("Migrate %s timeout.", migration_thread)
-                    self.RET_LOCK.acquire()
-                    self.RET_MIGRATION = False
-                    self.RET_LOCK.release()
+                _do_orderly_migration(vm.name, vm, srcuri, desturi,
+                                      options=options,
+                                      thread_timeout=thread_timeout,
+                                      ignore_status=ignore_status, func=func,
+                                      virsh_opt=virsh_opt,
+                                      extra_opts=extra_opts, **args)
         elif migration_type == "cross":
             # Migrate a vm to remote first,
             # then migrate another to remote with the first vm back
@@ -359,6 +386,9 @@ class MigrationTest(object):
         if not self.RET_MIGRATION and not ignore_status:
             raise exceptions.TestFail()
 
+        logging.info("Checking migration result...")
+        self.check_result(self.ret, args)
+
     def cleanup_dest_vm(self, vm, srcuri, desturi):
         """
         Cleanup migrated vm on remote host.
@@ -374,6 +404,20 @@ class MigrationTest(object):
         # Set connect uri back to local uri
         vm.connect_uri = srcuri
 
+    def cleanup_vm(self, vm, desturi):
+        """
+        Cleanup migrated vm on remote host and local host
+
+        :param vm: vm object
+        :param desturi: uri for remote access
+        """
+        try:
+            self.cleanup_dest_vm(vm, vm.connect_uri, desturi)
+        except Exception as err:
+            logging.error(err)
+        if vm.is_alive():
+            vm.destroy(gracefully=False)
+
     def wait_for_migration_start(self, vm, state='paused', uri=None,
                                  migrate_options='', timeout=60):
         """
@@ -425,6 +469,36 @@ class MigrationTest(object):
             if arg and arg.count("EXAMPLE"):
                 raise exceptions.TestCancel("Please assign a value for %s!" % arg)
 
+    def update_virsh_migrate_extra_args(self, params):
+        """
+        Update extra arguments for the function executed during migration
+
+        :param params: the parameters used
+        :return: the updated extra arguments
+        """
+        func_params_exists = "yes" == params.get(
+            "action_during_mig_params_exists", "no")
+        wait_for_event = eval(params.get("wait_for_event", "False"))
+        event_type = params.get("event_type", None)
+        event_timeout = eval(params.get("event_timeout", "7"))
+
+        extra_args = {}
+        if func_params_exists:
+            if params.get("action_during_mig_params"):
+                extra_args.update({'func_params': eval(
+                    params.get("action_during_mig_params"))})
+            else:
+                extra_args.update({'func_params': params})
+
+        # Update parameters for postcopy migration
+        extra_args.update({'wait_for_event': wait_for_event})
+        extra_args.update({'event_type': event_type})
+        extra_args.update({'event_timeout': event_timeout})
+
+        extra_args.update({'status_error': params.get("status_error", "no")})
+        extra_args.update({'err_msg': params.get("err_msg")})
+        return extra_args
+
     def check_result(self, result, params):
         """
         Check if the migration result is as expected
