@@ -12,6 +12,7 @@ import ovirtsdk4 as sdk
 import ovirtsdk4.types as types
 
 from virttest import virt_vm
+from virttest.utils_net import ping
 
 
 _api = None
@@ -49,17 +50,11 @@ def connect(params):
     url = params.get('ovirt_engine_url')
     username = params.get('ovirt_engine_user')
     password = params.get('ovirt_engine_password')
-    version = params.get('ovirt_engine_version')
 
     if not all([url, username, password]):
         logging.error('ovirt_engine[url|user|password] are necessary!!')
 
-    if version is None:
-        version = types.Version(major='4', minor='2')
-    else:
-        version = types.Version(version)
-
-    global connection, _connected
+    global connection, _connected, version
 
     try:
         # Try to connect oVirt API if connection doesn't exist,
@@ -71,6 +66,7 @@ def connect(params):
                 password=password,
                 insecure=True
             )
+            version = connection.system_service().get().product_info.version
             _connected = True
             return connection, version
         else:
@@ -590,12 +586,16 @@ class VMManager(virt_vm.BaseVM):
         :raise VMIPAddressMissingError: If no IP address is found for the the
                 NIC's MAC address
         """
+        def is_ip_reachable(ipaddr):
+            res, _ = ping(ipaddr, timeout=5)
+            return res == 0
+
         nic = self.virtnet[index]
         if nic.nettype == 'bridge':
             mac = self.get_mac_address()
             for mac_i in mac:
                 ip = self.address_cache.get(mac_i)
-                if ip:
+                if ip and is_ip_reachable(ip):
                     return ip
             # TODO: Verify MAC-IP address mapping on remote ovirt node
             raise virt_vm.VMIPAddressMissingError(mac)
