@@ -386,8 +386,8 @@ def create_partition_linux(session, did, size, start,
         driver = "pci"
         if platform.machine() == "s390x":
             driver = "css0"
-        o = session.cmd('ls /sys/dev/block -l | grep "/%s" | grep "%s"' %
-                        (driver, did))
+        o = session.cmd('ls /sys/dev/block -l | grep "/%s" | grep "%s" '
+                        '--color=never' % (driver, did))
         return set(o.splitlines())
 
     size = utils_numeric.normalize_data_size(size, order_magnitude="M") + "M"
@@ -1102,6 +1102,23 @@ def get_parts_list(session=None):
     return parts
 
 
+def get_first_disk(session=None):
+    """
+    Get the first disk device on host or guest
+
+    :param session: the vm session
+    :return: str, the disk device, like 'vda' or 'sda'
+    """
+    first_disk = ""
+    disks = get_parts_list(session=session)
+    for disk in disks:
+        pattern = re.compile('[0-9]+')
+        if not pattern.findall(disk):
+            first_disk = disk
+            break
+    return first_disk
+
+
 def get_disk_by_serial(serial_str, session=None):
     """
     Get disk by serial in VM or host
